@@ -696,7 +696,7 @@ public class CacheUtil {
             path.append(location.getPort());
             path.append(File.separatorChar);
         }
-        String locationPath = location.getPath().replace('/', File.separatorChar);
+        String locationPath = location.getPath();
         String query = "";
         if (location.getQuery() != null) {
             query = location.getQuery();
@@ -716,7 +716,7 @@ public class CacheUtil {
                 throw new RuntimeException(ex);
             }
         } else {
-            path.append(locationPath);
+            path.append(locationPath.replace('/', File.separatorChar));
             if (location.getQuery() != null && !location.getQuery().trim().isEmpty()) {
                 path.append(".").append(location.getQuery());
             }
@@ -877,7 +877,7 @@ public class CacheUtil {
                     rStr = lruHandler.getCacheDir().getFullPath()+ rStr.substring(0, rStr.indexOf(File.separatorChar, 1));
                     long len = file.length();
 
-                    if (keep.contains(file.getPath().substring(rStr.length()))) {
+                    if (keep.contains(path)) {
                         lruHandler.removeEntry(key);
                         continue;
                     }
@@ -897,7 +897,7 @@ public class CacheUtil {
                     }
 
                     curSize += len;
-                    keep.add(file.getPath().substring(rStr.length()));
+                    keep.add(path);
 
                     for (File f : file.getParentFile().listFiles()) {
                         if (!(f.equals(file) || f.equals(pf.getStoreFile()))) {
